==> pan-0.6.1.tar.gz: pan-0.6.1/pan/db.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __DB_H__
#define __DB_H__

#include <gdbm.h>

void          db_save_articles    (group_data *, GSList *, int);
void          db_erase_article    (article_data *);
GSList*       db_load_articles    (group_data *);
article_data* article_db_fetch    (gchar *);
int           group_index_exists  (group_data *);
void          group_index_erase   (group_data *);
void          db_open             (void);
void          db_close            (void);
void          db_store_article    (group_data *, article_data *);
article_data* db_fetch_article    (group_data *, gchar *);
int save_article_gslist (GSList *p, GDBM_FILE dbf, int count, int total);


int db_group_index_erase (group_data *gdata);

#endif /* __DB_H__ */

==> pan-0.6.2.tar.gz: pan-0.6.2/pan/db.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __DB_H__
#define __DB_H__

#include <gdbm.h>

void          db_save_articles    (group_data *, GSList *, int);
void          db_article_erase    (article_data *);
GSList*       db_load_articles    (group_data *);
article_data* article_db_fetch    (gchar *);
int           group_index_exists  (group_data *);
void          group_index_erase   (group_data *);
void          db_open             (void);
void          db_close            (void);
void          db_store_article    (group_data *, article_data *);
article_data* db_fetch_article    (group_data *, gchar *);
int save_article_gslist (GSList *p, GDBM_FILE dbf, int count, int total);


int db_group_index_erase (group_data *gdata);

#endif /* __DB_H__ */
